# geoquizzy


[![image](https://img.shields.io/pypi/v/geoquizzy.svg)](https://pypi.python.org/pypi/geoquizzy)
[![image](https://img.shields.io/conda/vn/conda-forge/geoquizzy.svg)](https://anaconda.org/conda-forge/geoquizzy)


**a fun geography quiz game**


-   Free software: MIT license
-   Documentation: https://bassneel.github.io/geoquizzy
    

## Features

-   TODO
